==> dhall-yaml-1.2.12-166-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-Le3URnZBhQf8xv6bzH8QP0
key:                  dhall-yaml-1.2.12-Le3URnZBhQf8xv6bzH8QP0
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  7bfc7301add3aaebff4e926a07d0be8a
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-Le3URnZBhQf8xv6bzH8QP0
depends:
    HsYAML-0.2.1.5-LCvWSQv2Ku5HL4QY5OHlCf
    HsYAML-aeson-0.2.0.2-LF8EqBS47OaA4KQXvZYcZL
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 dhall-1.42.3-KXmenYTki91GraQt2ymkdK
    dhall-json-1.7.12-EJ5Z9F6sPMpHqY1RMzFO9X
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE text-2.0.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.12-169-loong64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-8NvhNOwGbEmErJSGUkLZVI
key:                  dhall-yaml-1.2.12-8NvhNOwGbEmErJSGUkLZVI
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  232273023db1fae97f5a4c9f2cd4b987
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-8NvhNOwGbEmErJSGUkLZVI
depends:
    HsYAML-0.2.1.5-5ALdEUiBZBy68ckkwtJ8RG
    HsYAML-aeson-0.2.0.2-4CWU1VzZuSk4saVKtjHz33
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    bytestring-0.11.5.3 dhall-1.42.3-6ivmxcjn5ctBDS3CQUifdU
    dhall-json-1.7.12-DNkntXMNk15AAJ0w8mbM6T
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
